@@ -2,7 +2,7 @@ from arc.middleware import Middleware
 from arc.defaults import DefaultMiddleware, DefaultExceptionHandler
 from jinja2.loaders import FileSystemLoader
 from webob import Request, Response
-from cheroot.wsgi import Server
+import uvicorn
 from parse import parse
 from jinja2 import Environment, FileSystemLoader
 from whitenoise import WhiteNoise
@@ -10,17 +10,78 @@ import socket
 import inspect
 import os
 import traceback
-import pathlib
 
 
 class App:
-    def __init__(self, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000, default_middleware=True):
-        self.routes = {}
-        self.host = host
-        self.port = port
+    """
+    The base App object. This object creates a WSGI application, and is used as the base object for creating routes, views, 
+    templating, and more. Basic usage is as the following:: 
+    
+    from arc import App
+    
+    app = App("app")
+    
+    @app.route("/")
+    def index(req, res):
+        res.text = 'Hello, World'
+    
+    if __name__ == "__main__":
+        app.run()
+    
+    The app has several parameters.
+    
+    ..name ::
+        This paramter is used to specifiy the apps name. It is required, and has to be the same as the variable name
+        you assigned the App class to.
+        
+        app = App("app")
+        
+    
+    ..templates_dir ::
+        This parameter is used to specify the directory that jinja loads its HTML templates from. Its defaulted to 
+        the 'templates' directory, but you can change it as the following::
+        
+        app = App(templates_dir="public")
+        
+    ..static_dir ::
+        This parameter is used to specify the directory that static files are served from. Its defaulted to the
+        'static' folder. You can change it as the following::
+        
+        app = App(static_dir="css")
+        
+    ..exception_handler ::
+        This parameter is used to specify a custom exception handler for the app to use instead of the default
+        one. It uses the base AppException class. It's defaulted to None, which causes the app to use the
+        default exception handler. It can be changed as the following::
+        
+        app = App(exception_handler=CustomExceptionHandler)
+        
+    ..host ::
+        This parameter is used to specify the host that the app will run on. Its defaulted 
+        to '127.0.0.1'. It can be changed as the following::
+        
+        app = App(host="181.177.121.773")
+        
+    ..port ::
+        This parameter is used to specify which port the app will listen on. Its defaulted to 
+        port `5000`. You can change it as the following::
 
-        self.cur_resp = None
-        self.cur_req = None
+        app = App(port=8000)
+    
+    ..default_middleware
+        This parameter specifies whether the app should use the default middleware, which logs requests and
+        responses into the console. Its set to True by default. You can change it as the following::
+        
+        app = App(default_middleware=False)
+    """
+    def __init__(self, name, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000, default_middleware=True):
+        self.routes = {}
+        
+        #The host
+        self.host = host
+        
+        #The port
+        self.port = port
 
         self.templates_dir = templates_dir
 
@@ -47,16 +108,7 @@ class App:
             request_queue_size=500,
             server_name=socket.gethostname()
         )
-        
-        # dir_path = os.path.dirname(os.path.realpath(__file__))
-        # path = os.path.join(self.dir_path, "selfpages")
-        # dashboard_env = Environment(
-        #     loader=FileSystemLoader(os.path.join(self.dir_path, "selfpages")))
-        
-        # def default_app_dashboard(req, res):
-        #     res.body = dashboard_env.get_template("default-dashboard.html").render({"app_host": self.host, "app_port": self.port}).encode()
-        
-        # self.add_route("/default-app-dashboard", default_app_dashboard)
+
 
     def wsgi_app(self, environ, start_response):
         request = Request(environ)
@@ -172,11 +224,6 @@ class App:
         self.collections.append(collection)
 
     def run(self):
-        try:
-            print(f"[INFO] Running on http://{self.host}:{self.port}")
-            print(f"[INFO] Press CTRL + C to stop")
-            self.server.start()
-        except KeyboardInterrupt:
-            print("\n")
-            print(f"[INFO] Exiting Application")
-            self.server.stop()
+        print(f"[INFO] Running on http://{self.host}:{self.port}")
+        print(f"[INFO] Press CTRL + C to stop")
+        uvicorn.run(f'{inspect.stack()[1][1].replace(".py", "")}:{self.name}', host="127.0.0.1", port=5000, log_level="error", interface="wsgi")
